@@ -20,7 +20,7 @@
 #'   a (n x K) matrix of probabilities (with row-sums 1).
 #'   The observed values `y` are either passed as (n x K) dummy matrix, 
 #'   or as discrete vector with corresponding levels. 
-#'   The latter case is turned into a dummy matrix via 
+#'   The latter case is turned into a dummy matrix by a fast version of
 #'   `model.matrix(~ as.factor(y) + 0)`.
 #' - "classification_error": Misclassification error. Both the 
 #'   observed values `y` and the predictions can be character/factor. This
@@ -37,8 +37,10 @@
 #'   can be provided that turns observed and predicted values into a numeric vector or 
 #'   matrix of unit losses of the same length as `X`.
 #'   For "mlogloss", the response `y` can either be a dummy matrix or a discrete vector. 
-#'   The latter case is handled via `model.matrix(~ as.factor(y) + 0)`.
+#'   The latter case is handled via a fast version of `model.matrix(~ as.factor(y) + 0)`.
 #'   For "classification_error", both predictions and responses can be non-numeric.
+#'   For "squared_error", both predictions and responses can be factors with identical
+#'   levels. In this case, squared error is evaulated for each one-hot-encoded column.
 #' @param agg_cols Should multivariate losses be summed up? Default is `FALSE`.
 #'   In combination with the squared error loss, `agg_cols = TRUE` gives
 #'   the Brier score for (probabilistic) classification.
@@ -57,10 +59,10 @@
 #' average_loss(fit, X = iris, y = "Sepal.Length", BY = "Sepal.Width")
 #'
 #' # MODEL 2: Multi-response linear regression
-#' fit <- lm(as.matrix(iris[1:2]) ~ Petal.Length + Petal.Width + Species, data = iris)
-#' average_loss(fit, X = iris, y = iris[1:2])
+#' fit <- lm(as.matrix(iris[, 1:2]) ~ Petal.Length + Petal.Width + Species, data = iris)
+#' average_loss(fit, X = iris, y = iris[, 1:2])
 #' L <- average_loss(
-#'   fit, X = iris, y = iris[1:2], loss = "gamma", BY = "Species"
+#'   fit, X = iris, y = iris[, 1:2], loss = "gamma", BY = "Species"
 #' )
 #' L
 #' plot(L)
@@ -92,8 +94,8 @@ average_loss.default <- function(object, X, y,
   }
   
   # Real work
-  L <- as.matrix(loss(y, pred_fun(object, X, ...)))
-  M <- gwColMeans(L, g = BY, w = w)
+  pred <- prepare_pred(pred_fun(object, X, ...))
+  M <- gwColMeans(loss(y, pred), g = BY, w = w)[["M"]]
   
   if (agg_cols && ncol(M) > 1L) {
     M <- cbind(rowSums(M))
